==> vtk-6.3.0-5-armv7h.pkg.tar.xz: vtk/vtkDiskSource.java <==
// java wrapper for vtkDiskSource object
//

package vtk;
import vtk.*;

public class vtkDiskSource extends vtkPolyDataAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetInnerRadius_2(double id0);
  public void SetInnerRadius(double id0)
    { SetInnerRadius_2(id0); }

  private native double GetInnerRadiusMinValue_3();
  public double GetInnerRadiusMinValue()
    { return GetInnerRadiusMinValue_3(); }

  private native double GetInnerRadiusMaxValue_4();
  public double GetInnerRadiusMaxValue()
    { return GetInnerRadiusMaxValue_4(); }

  private native double GetInnerRadius_5();
  public double GetInnerRadius()
    { return GetInnerRadius_5(); }

  private native void SetOuterRadius_6(double id0);
  public void SetOuterRadius(double id0)
    { SetOuterRadius_6(id0); }

  private native double GetOuterRadiusMinValue_7();
  public double GetOuterRadiusMinValue()
    { return GetOuterRadiusMinValue_7(); }

  private native double GetOuterRadiusMaxValue_8();
  public double GetOuterRadiusMaxValue()
    { return GetOuterRadiusMaxValue_8(); }

  private native double GetOuterRadius_9();
  public double GetOuterRadius()
    { return GetOuterRadius_9(); }

  private native void SetRadialResolution_10(int id0);
  public void SetRadialResolution(int id0)
    { SetRadialResolution_10(id0); }

  private native int GetRadialResolutionMinValue_11();
  public int GetRadialResolutionMinValue()
    { return GetRadialResolutionMinValue_11(); }

  private native int GetRadialResolutionMaxValue_12();
  public int GetRadialResolutionMaxValue()
    { return GetRadialResolutionMaxValue_12(); }

  private native int GetRadialResolution_13();
  public int GetRadialResolution()
    { return GetRadialResolution_13(); }

  private native void SetCircumferentialResolution_14(int id0);
  public void SetCircumferentialResolution(int id0)
    { SetCircumferentialResolution_14(id0); }

  private native int GetCircumferentialResolutionMinValue_15();
  public int GetCircumferentialResolutionMinValue()
    { return GetCircumferentialResolutionMinValue_15(); }

  private native int GetCircumferentialResolutionMaxValue_16();
  public int GetCircumferentialResolutionMaxValue()
    { return GetCircumferentialResolutionMaxValue_16(); }

  private native int GetCircumferentialResolution_17();
  public int GetCircumferentialResolution()
    { return GetCircumferentialResolution_17(); }

  private native void SetOutputPointsPrecision_18(int id0);
  public void SetOutputPointsPrecision(int id0)
    { SetOutputPointsPrecision_18(id0); }

  private native int GetOutputPointsPrecision_19();
  public int GetOutputPointsPrecision()
    { return GetOutputPointsPrecision_19(); }

  public vtkDiskSource() { super(); }

  public vtkDiskSource(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.1.0-3-armv7h.pkg.tar.xz: vtk/vtkDiskSource.java <==
// java wrapper for vtkDiskSource object
//

package vtk;
import vtk.*;

public class vtkDiskSource extends vtkPolyDataAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetInnerRadius_2(double id0);
  public void SetInnerRadius(double id0)
    { SetInnerRadius_2(id0); }

  private native double GetInnerRadiusMinValue_3();
  public double GetInnerRadiusMinValue()
    { return GetInnerRadiusMinValue_3(); }

  private native double GetInnerRadiusMaxValue_4();
  public double GetInnerRadiusMaxValue()
    { return GetInnerRadiusMaxValue_4(); }

  private native double GetInnerRadius_5();
  public double GetInnerRadius()
    { return GetInnerRadius_5(); }

  private native void SetOuterRadius_6(double id0);
  public void SetOuterRadius(double id0)
    { SetOuterRadius_6(id0); }

  private native double GetOuterRadiusMinValue_7();
  public double GetOuterRadiusMinValue()
    { return GetOuterRadiusMinValue_7(); }

  private native double GetOuterRadiusMaxValue_8();
  public double GetOuterRadiusMaxValue()
    { return GetOuterRadiusMaxValue_8(); }

  private native double GetOuterRadius_9();
  public double GetOuterRadius()
    { return GetOuterRadius_9(); }

  private native void SetRadialResolution_10(int id0);
  public void SetRadialResolution(int id0)
    { SetRadialResolution_10(id0); }

  private native int GetRadialResolutionMinValue_11();
  public int GetRadialResolutionMinValue()
    { return GetRadialResolutionMinValue_11(); }

  private native int GetRadialResolutionMaxValue_12();
  public int GetRadialResolutionMaxValue()
    { return GetRadialResolutionMaxValue_12(); }

  private native int GetRadialResolution_13();
  public int GetRadialResolution()
    { return GetRadialResolution_13(); }

  private native void SetCircumferentialResolution_14(int id0);
  public void SetCircumferentialResolution(int id0)
    { SetCircumferentialResolution_14(id0); }

  private native int GetCircumferentialResolutionMinValue_15();
  public int GetCircumferentialResolutionMinValue()
    { return GetCircumferentialResolutionMinValue_15(); }

  private native int GetCircumferentialResolutionMaxValue_16();
  public int GetCircumferentialResolutionMaxValue()
    { return GetCircumferentialResolutionMaxValue_16(); }

  private native int GetCircumferentialResolution_17();
  public int GetCircumferentialResolution()
    { return GetCircumferentialResolution_17(); }

  private native void SetOutputPointsPrecision_18(int id0);
  public void SetOutputPointsPrecision(int id0)
    { SetOutputPointsPrecision_18(id0); }

  private native int GetOutputPointsPrecision_19();
  public int GetOutputPointsPrecision()
    { return GetOutputPointsPrecision_19(); }

  public vtkDiskSource() { super(); }

  public vtkDiskSource(long id) { super(id); }
  public native long   VTKInit();

}
